%%
%% This is file `envexecjs.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% aeb_envelope.dtx  (with options: `copyright,envexecjs')
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% aeb_envelope.sty package,          2007-05-14        %%
%% Copyright (C) 2006  D. P. Story                      %%
%%   dpstory@acrotex.net                                %%
%%   storyd@owc.edu                                     %%
%%                                                      %%
%% This program can redistributed and/or modified under %%
%% the terms of the LaTeX Project Public License        %%
%% Distributed from CTAN archives in directory          %%
%% macros/latex/base/lppl.txt; either version 1 of the  %%
%% License, or (at your option) any later version.      %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % the eEnvelope out to your recipients.
\begin{execJS}{envexecjs}
global.oEmailArgs = {
    bUI:\mailtoUI,
    cTo: "\mailtoEmail",
    cCc: "\mailtoCC",
    cBcc: "\mailtoBCC",
    cSubject: "\mailtoSubject",
    cMsg: "\mailtoMessageBody"
};
\addWatermarkFromFile({
    bOnTop:false,
    cDIPath:"\pathtoEnv"
});
function mailItNow()
{
    try { this.mailDoc(global.oEmailArgs) } catch(e) {}
}
console.println("mailItNow();");
\executeSave();
if ( \mailitNow\space)
    aebTrustedFunctions(this, aebMailDoc, global.oEmailArgs);
\end{execJS}
\endinput
%%
%% End of file `envexecjs.def'.
